<?php
App::uses('CustomEmail', 'Lib');

class InjectContactFormComponent extends Component {

	private $Controller;
	
	public function initialize($Controller){
		$this->Controller = $Controller;
	}

	public function display($id, $name) {
		$this->Controller->loadModel('ContactForm');
		$this->Controller->loadModel('ContactFormResponse');

		$form = $this->Controller->ContactForm->find('first', array('conditions' => array(
				'ContactForm.id' => $id
		)));
		if (empty($form['ContactForm'])) {
			return false;
		}
		$config= Configure::read('EvContactForm');
		$contactFormData = $config[$form['ContactForm']['form_data']];
		$formData = $contactFormData;
		$fields = $contactFormData['fields'];

		if ($this->Controller->request->is('post') && ! empty($this->Controller->request->data[$name])) {

			// setup the dynamic validation
			foreach ($fields as $field => $options) {

				if (! empty($options['validate'])) {

					foreach ($options['validate'] as $rule => $rule_data) {

						$this->Controller->ContactFormResponse->validator()->add($field, $rule, $rule_data);
					}
				}
			}

			// validate!
			if ($this->Controller->ContactFormResponse->validator()->validateAssociated($this->Controller->request->data[$name])) {

				// passed validation, remove rules so we can add to the database
				foreach ($fields as $field => $options) {

					if (! empty($options['validate'])) {

						$this->Controller->ContactFormResponse->validator()->remove($field);
					}
				}

				// serialize it
				$contact_form_data = serialize($this->Controller->request->data[$name]);

				// name label
				$name_lbl = $formData['name_label'];

				if (! empty($this->Controller->request->data[$name]['ContactFormResponse'][$name_lbl])) {
					$responseName = $this->Controller->request->data[$name]['ContactFormResponse'][$name_lbl];
				} else {
					$responseName = 'Unknown Name';
				}




				$data = array(
					'ContactFormResponse' => array(
						'contact_form_id' => $form['ContactForm']['id'],
						'name' => $responseName,
						'form_data' => $contact_form_data,
						'created' => date('Y-m-d H:i:s')
					)
				);
				$this->Controller->set($name . '_completed', true);
				// save it
				if ($this->Controller->ContactFormResponse->save($data)) {

					 $email_from = array(
						'name' => Configure::read('SiteSetting.site_title'),
						'email' => Configure::read('SiteSetting.admin_email'),
					);
					$email_to = explode(',', $form['ContactForm']['email_to']);

					if (! is_null($email_from) && ! is_null($email_to)) {

						// send the email!

						$email = new CustomEmail();
						$email->template('EvContactForm.contact_form_notification')
							->from($email_from['email'], (isset($email_from['name'])) ? $email_from['name'] : null)
							->emailFormat('html')
							->subject($form['ContactForm']['subject'])
							->viewVars(array(
								'form_data' => $this->Controller->request->data[$name],
								'fields' => $fields
							));
						// build the to / cc's
						$to = array_shift($email_to);


						$email->to($to);

						if (! empty($email_to)) {
							foreach ($email_to as $recipient) {
								$email->addCc($recipient);
							}
						}
						$email->send();

					}

					// unset form data nad show success
					unset($this->Controller->request->data[$name]);
					if (isset($formData['flash_message']) && $formData['flash_message']) {
						$this->Controller->Session->setFlash('Your message has been sent', 'flash_success');
					}
					$this->Controller->set($name . '_sent', true);
				} else {
					if (isset($formData['flash_message']) && $formData['flash_message']) {
						$this->Controller->Session->setFlash('There was an issue saving your message, please try again', 'flash_fail');
					}
					// failed to save, error
					$contact_form_errors = array(
						'There was an issue saving your message, please try again'
					);

					$this->Controller->set($name . '_errors', $contact_form_errors);
				}

			} else {

				// compile the validate errors
				
				$this->Controller->Session->setFlash('Please check you have filled out all the required fields', 'flash_fail');

				$contact_form_errors = array();

				foreach ($this->Controller->ContactFormResponse->validationErrors as $field => $errors) {
					foreach ($errors as $msg) {
						$contact_form_errors[] = $msg;
					}
				}

				// I dont know why I need this
				if (isset($this->Controller->request->data[$name][$name])) {
					$temp = $this->Controller->request->data[$name][$name];
					$this->Controller->request->data[$name] = $temp;
				}
				$this->Controller->set($name . '_errors', $contact_form_errors);
			}
		}

		$this->Controller->set($name . '_form', $formData);
	}
}
?>